@@ -1,3 +1,4 @@
+import os
 import time
 from datetime import timezone
 from jsoncustom import JsonCustom
@@ -144,7 +145,7 @@ class ABSVTBToken(ABSVTBBigFather):
 
 
 class ABSVTBFather(ABSVTBBigFather):
-    path_vtb_token = None
+    path_vtb_token = f'{os.path.abspath(os.curdir)}/vtb_api_token.json'
 
     def __init__(self, json):
         super().__init__()
